{{/*
Common labels
*/}}
{{- define "lambda.labels" -}}
{{ include "lambda-utils.labels" . }}
{{- end -}}

{{/*
Selector labels
*/}}
{{- define "lambda.selectorLabels" -}}
{{ include "lambda-utils.selectorLabels" . }}
{{- end -}}

{{/*
  EC release name
*/}}
{{- define "lambda.ecReleaseName" -}}
{{ required "You must specify the service to find." .Values.ecVar.releaseName }}
{{- end -}}

{{/*
  EC release alias
*/}}
{{- define "lambda.ecAlias" -}}
{{ required "You must specify the service to find." .Values.ecVar.alias }}
{{- end -}}

{{/*
  Lambda for ec token secret
*/}}
{{- define "lambda.ecTokenSecret" -}}
{{ include "lambda.ecReleaseName" . }}-{{ include "lambda.ecAlias" . }}-ec-pass
{{- end -}}

{{/*
  Lambda for ec endpoint configmap
*/}}
{{- define "lambda.ecEndpointConfigMap" -}}
{{ include "lambda.ecReleaseName" . }}-{{ include "lambda.ecAlias" . }}-endpoint
{{- end -}}


{{/*
  Lambda for ec token
*/}}
{{- define "lambda.ecVar" -}}
{{- if .Values.ecVar -}}
{{- if .Values.ecVar.enable -}}
ecVar: "true"
ecReleaseName: {{ include "lambda.ecReleaseName" . | quote }}
ecAlias: {{ include "lambda.ecAlias" . | quote }}
ecTokenEnvName: {{ required "You must specify the token ENV name" .Values.ecVar.envNames.token | quote }}
ecEndpointEnvName: {{ required "You must specify the service ENV name" .Values.ecVar.envNames.endpoint | quote }}
{{- end -}}
{{- end -}}
{{- end -}}

{{/*
  Postgres release name
*/}}
{{- define "lambda.pgReleaseName" -}}
{{ required "You must specify the service to find." .Values.pgVar.releaseName }}
{{- end -}}

{{/*
  Postgres release alias
*/}}
{{- define "lambda.pgAlias" -}}
{{ required "You must specify the service to find." .Values.pgVar.alias }}
{{- end -}}

{{/*
  Lambda for postgres username secret
*/}}
{{- define "lambda.pgUsernameSecret" -}}
{{ include "lambda.pgReleaseName" . }}-{{ include "lambda.pgAlias" . }}-pg-user
{{- end -}}

{{/*
  Lambda for postgres password secret
*/}}
{{- define "lambda.pgPasswordSecret" -}}
{{ include "lambda.pgReleaseName" . }}-{{ include "lambda.pgAlias" . }}-pg-pass
{{- end -}}

{{/*
  Lambda for postgres password secret
*/}}
{{- define "lambda.pgEndpointConfigMap" -}}
{{ include "lambda.pgReleaseName" . }}-{{ include "lambda.pgAlias" . }}-endpoint
{{- end -}}

{{/*
  Lambda for postgres reader endpoint service
*/}}
{{- define "lambda.pgReaderEndpointService" -}}
{{ include "lambda.pgReleaseName" . }}-{{ include "lambda.pgAlias" . }}-reader-endpoint
{{- end -}}

{{/*
  Lambda postgres secrets
*/}}
{{- define "lambda.pgVar" -}}
{{- if .Values.pgVar -}}
{{- if .Values.pgVar.enable -}}
pgVar: "true"
pgReleaseName: {{ include "lambda.pgReleaseName" . | quote }}
pgAlias: {{ include "lambda.pgAlias" . | quote }}
pgUsernameEnvName: {{ required "You must specify the username ENV name" .Values.pgVar.envNames.username | quote }}
pgPasswordEnvName: {{ required "You must specify the password ENV name" .Values.pgVar.envNames.password | quote }}
pgEndpointEnvName: {{ required "You must specify the service ENV name" .Values.pgVar.envNames.endpoint | quote }}
pgReaderEndpointEnvName: {{ required "You must specify the reader service ENV name" .Values.pgVar.envNames.readerEndpoint | quote }}
{{- end -}}
{{- end -}}
{{- end -}}

{{/*
  Lambda mount vars
*/}}
{{- define "lambda.infraEnvMount" -}}
{{- if .Values.infraEnvMount -}}
infraEnvMount: {{ .Values.infraEnvMount | toJson | quote }}
{{- end -}}
{{- end -}}

{{/*
  Lambda mount additional Global vars
*/}}
{{- define "lambda.additionalGlobalVars" -}}
{{- if eq .Values.includeDefaultEnvVars false }}
cspEndpoint: {{ .Values.global.cspEndpoint | quote }}
{{- end -}}
{{- end -}}


{{/*
  Default Lambda vars taken from global values, excluding AWS_REGION,
  with special vars for WAVEFRONT_PROXY, WAVEFRONT_URL, WAVEFRONT_PORT, STATSD_PORT
  Blank when includeDefaultEnvVars is false.
*/}}
{{- define "lambda.defaultLambdaEnvVars" -}}
{
  {{- if eq .Values.includeDefaultEnvVars true }}
  {{- range $key, $value := .Values.global }}
  {{- if kindIs "map" $value }}
  {{- range $mapkey, $mapvalue := $value }}
  {{ cat $key ( title $mapkey ) | snakecase | upper }} = {{ $mapvalue | quote }},
  {{- end }}
  {{- else if ne $key "awsRegion" }}
  {{ $key | snakecase | upper }} = {{ $value | quote }},
  {{- end -}}
  {{- end }}
  {{- if .Values.global.wavefrontProxy -}}
  {{- if .Values.global.wavefrontProxy.name }}
  WAVEFRONT_PROXY = {{ .Values.global.wavefrontProxy.name | quote }},
  {{- end }}
  {{- if .Values.global.wavefrontProxy.externalDns }}
  WAVEFRONT_URL = {{ .Values.global.wavefrontProxy.externalDns | quote }},
  {{- end }}
  {{- if .Values.global.wavefrontProxy.port }}
  WAVEFRONT_PORT = {{ .Values.global.wavefrontProxy.port | quote }},
  {{- end }}
  {{- end -}}
  {{- if .Values.global.telegrafProxy -}}
  {{- if .Values.global.telegrafProxy.statsdPort }}
  STATSD_PORT = {{ .Values.global.telegrafProxy.statsdPort | quote }},
  {{- end }}
  {{- end }}
  {{- end }}
  {{ .Values.internalIngressHostEnvName }} = "{{ default "app" .Values.global.subDomain }}-internal.{{- required "global.host is a required value. Define it in your env definitions yaml." .Values.global.host }}",
  {{ .Values.externalIngressHostEnvName }} = "{{ default "app" .Values.global.subDomain }}.{{- required "global.host is a required value. Define it in your env definitions yaml." .Values.global.host }}",
  {{ .Values.csrIngressHostEnvName }} = "{{ default "app" .Values.global.subDomain }}-csr.{{- required "global.host is a required value. Define it in your env definitions yaml." .Values.global.host }}"
}
{{- end -}}

{{/*
  Lambda extra vars
*/}}
{{- define "lambda.extraVars" -}}
{{- if .Values.extraVariables -}}
extraVar: "true"
vars: {{ .Values.extraVariables | toJson | quote }}
{{- end -}}
{{- end -}}


{{/*
    Lambda image/registry function
*/}}
{{- define "lambda.registryPrefixWithImageLambda" -}}
{{- if .Values.lambdaImageName }}
{{- include "lambda-utils._registryPrefix" . }}/{{ required "lambdaImageName  is a required value" .Values.lambdaImageName }}:{{ required "lambdaImageVersion  is a required value" .Values.lambdaImageVersion }}
{{- else -}}
{{ include "lambda-utils.registryPrefixWithImage" . }}
{{- end -}}
{{- end -}}

{{/*
    Lambda resource-based policies
*/}}
{{- define "lambda.resourceBasedPolicyService" -}}
{{ if contains "gov" .Values.global.awsRegion -}}
{{- printf "\n\nThe resourceBasedPolicy is not supported in gov environments." | fail -}}
{{- else -}}
[
  {{- range $value := .Values.resourceBasedPolicy.policies_aws_service -}}
    {
    {{- range $kk, $vv := $value }}
        {{ $kk }} : {{ $vv | quote}}
    {{- end }}
    },
  {{- end -}}
]
{{- end -}}
{{- end -}}